Package: fdth
Version: 1.5-0
Date: 2026-05-25
Title: Frequency Distribution Tables, Histograms and Polygons
Authors@R: c(person("J. C.", "Faria", role=c("aut","cre"),
               email="joseclaudio.faria@gmail.com"),
             person("I. B.", "Allaman", role="aut"),
             person("E. G.", "Jelihovschi", role="aut"))
Depends: R (>= 3.5.0)
Imports: xtable
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
VignetteBuilder: knitr
Description: Perform frequency distribution tables, associated histograms
             and polygons from vector, data.frame and matrix objects for
             numerical and categorical variables.
License: GPL (>= 2)
URL: https://github.com/jcfaria/fdth
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2026-05-25 20:21:54 UTC; jcfaria
Author: J. C. Faria [aut, cre],
  I. B. Allaman [aut],
  E. G. Jelihovschi [aut]
Maintainer: J. C. Faria <joseclaudio.faria@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-25 20:40:02 UTC
Built: R 4.5.2; ; 2026-05-25 22:14:34 UTC; unix
